/**
 * @file
 * Icon select javascript behaviours
 */

(function ($, Drupal, window, document) {
  'use strict';

  Drupal.behaviors.icon_select = {
    attach: function (context, settings) {

      settings.icon_select = settings.icon_select || drupalSettings.icon_select;

      var checkboxes = $('.icon-select-wrapper input[type="checkbox"]', context);
      var checkbox_wrapper = $('.icon-select-wrapper .form-type-checkbox', context);

      // Allowing using contextual links in such wrappers that are <a> tags.
      checkboxes.bind('click', function (e) {
        checkboxes.not(this).prop('checked', false);
        e.stopPropagation();
      });

      checkboxes.change(function () {
        $(this).closest('.icon-select-wrapper').find('.form-type-checkbox').removeClass('selected');
        $(this).closest('.form-item').toggleClass('selected', this.checked);
      });

      checkboxes.each(function () {
        if (this.checked) {
          $(this).closest('.form-item').toggleClass('selected', this.checked);
        }
      });

      // Activate checkbox on click of the parent item as well
      checkbox_wrapper.on('click', function (e) {
        var checkbox = $(this).find('input');
        checkbox.trigger('click');
      });

      $.ajax({
        url: settings.icon_select.icon_select_url,
        dataType: 'text',
        type: 'GET',
        async: true,
        success: function (response) {
          var new_div = $('<div>').append(response).html();
          $('body').prepend(new_div);
        }
      });
    }
  };

})(jQuery, Drupal, this, this.document);
